@@ -57,28 +57,25 @@ void printUsage()
 {
       cout << "Usage:" << endl;
       cout << PACKAGE
-	   << " [--returncode] [--file=datafile] <bank-id> <account-id>"
-	   << endl
-	   << "  --help: This help message"
-	   << endl
-	   << "  --bankdata-path: No checking, only print the default bankdata-path"
-	   << endl
-	   << "  --file=<bankdata-file>: Read bankdata from the specified file"
-	   << endl
-	   << "  --returncode: no output, result is returned via the returncode"
-	   << endl
-	   << "  --outformat=<format>: multiline (default), or oneline (tab-delimited) output"
-	   << endl
-	   << "  --infile=<filename>: Read many BLZ/accounts from filename, not cmdline"
-	   << endl
+	   << " [--returncode] [--file=datafile] <bank-id> <account-id>\n"
+	   << "  --help: This help message\n"
+	   << "  --version: Print the version number and exit.\n"
+	   << "  --bankdata-path: Print the path where bankdata files are expected, and exit.\n"
+           << "  --bankdata-looked-up: Print the looked-up bankdata file and path that \n"
+           << "                        will be used, and exit.\n"
+	   << "  --file=<bankdata-file>: Use this specified file as bankdata\n"
+	   << "  --returncode: Switch off output. Result is returned only via exit code\n"
+	   << "  --outformat=<format>: Choose output format: \"multiline\" (default), \n"
+           << "                        or \"oneline\" (tab-delimited) output\n"
+	   << "  --infile=<filename>: Read many BLZ/accounts from filename, not cmdline\n"
 	   << "  --outfile=<filename>: Write results to filename instead of stdout"
 	   << endl;
 
       cout
-	 << "                0: Everything is ok: account and bank match" << endl
-	 << "                1: Validation algorithm is unknown/unimplemented" << endl
-	 << "                2: Account and bank do not match" << endl
-	 << "                3: No bank with given bank-id found" << endl 
+	 << "                0: Everything is ok: account and bank match\n"
+	 << "                1: Validation algorithm is unknown/unimplemented\n"
+	 << "                2: Account and bank do not match\n"
+	 << "                3: No bank with given bank-id found\n" 
 	 << endl;
 
       exit(1);
@@ -103,6 +100,13 @@ void checkArg(string argument) {
       std::cout << "BANKDATA_PATH=" << AccountNumberCheck::bankdata_dir() << std::endl;
       exit(0);
    }
+
+   else if (argument == "--bankdata-looked-up") {
+       AccountNumberCheck anc;
+       std::string result = anc.getFilenameClosestDateToday();
+       std::cout << "BANKDATA_LOOKED_UP=" << result << std::endl;
+       exit(0);
+   }
   
    else if (argument == "--returncode") {
       nextArg++;
@@ -167,13 +171,15 @@ int main(int argc, char **argv) {
    if (bankdataFile.empty())
    {
       check_ptr = new AccountNumberCheck();
-      time_t mydate = time(NULL);//-24*3600*30*9;
-      if (!check_ptr->loadDataForDate(mydate))
-      {
-	 std::time_t x = check_ptr->closestValidData(mydate);
-	 std::cerr << PACKAGE ": Warning: The bankdata files which are known to your installed version of libktoblzcheck are not valid today.  If you think up-to-date files should be available, you will have to update the installed libktoblzcheck library as well.  The closest known available date with valid bankdata is: " << ctime(&x)
-		   << std::endl;
-      }
+//       time_t mydate = time(NULL);//-24*3600*30*9;
+//       if (!check_ptr->loadDataForDate(mydate))
+//       {
+// 	 std::time_t x = check_ptr->closestValidData(mydate);
+// 	 std::cerr << PACKAGE ": Warning: The bankdata files which are known to your installed version of libktoblzcheck are not valid today.  If you think up-to-date files should be available, you will have to update the installed libktoblzcheck library as well.  The closest known available date with valid bankdata is: " << ctime(&x)
+// 		   << std::endl;
+//       }
+      // No need to load the data file a second time - the default
+      // constructor already loads the most suitable file for today.
    }
    else 
    {
