@@ -198,6 +198,18 @@ AccountNumberCheck::AccountNumberCheck()
    }
 }
 
+std::string AccountNumberCheck::getFilenameClosestDateToday() const
+{
+   if (!dated_files.empty())
+   {
+       assert(!dated_files.empty());
+       FileDaterange file = find_closest_datafile(time(NULL));
+       return file.first;
+   }
+   else
+       return "";
+}
+
 AccountNumberCheck::AccountNumberCheck(const string& filename) 
     : 
     data() // std::map doesn't take size as argument
@@ -216,14 +228,18 @@ void AccountNumberCheck::init_datafile_list()
    // No files found? Maybe in the compiled-in installation location?
    if (dated_files.empty())
    {
+#ifdef BANKDATA_PATH
        populate_dated_files(BANKDATA_PATH, false);
+#endif
 
        // If there are still no files found, try again reading but now
        // print the file-not-found error messages.
        if (dated_files.empty())
        {
            populate_dated_files(bankdata_dir(), true);
+#ifdef BANKDATA_PATH
            populate_dated_files(BANKDATA_PATH, true);
+#endif
        }
    }
 }
