@@ -468,8 +468,7 @@ AccountNumberCheck::Result method_51_exception(const int *account, int *weight)
 	return algo01(11, weight, false, 10, account);	// Variant 2
 }
 // Added by Jens Gecius, validated with six test accountIDs
-// Checked with positive numbers for methods A, B, C
-// Exception handling see below
+// method 51 was extended for due-date 2013-06-03
 AccountNumberCheck::Result method_51(const int *account, int *weight) {
     // exception "Ausnahme f. Sachkonten"
     if (9 == account[2])
@@ -478,12 +477,19 @@ AccountNumberCheck::Result method_51(const int *account, int *weight) {
     number2Array("0007654320", weight);
     if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
 	return AccountNumberCheck::OK;	// Method A
+
     number2Array("0000654320", weight);
     if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
 	return AccountNumberCheck::OK;  // Method B
+
+    number2Array("0001212120", weight);
+    if (AccountNumberCheck::OK == algo01(10, weight, true, 10, account))
+	return AccountNumberCheck::OK;	// Method C
+
     if (7 == account[9] || 8 == account[9] || 9 == account[9])
 	return AccountNumberCheck::ERROR;  // Invalid IDs
-    return algo01(7, weight, false, 10, account); // Method C
+    number2Array("0000654320", weight);
+    return algo01(7, weight, false, 10, account); // Method D
 }
 AccountNumberCheck::Result method_52(const int *account, int *weight,
 				     const std::string& accountId, const std::string& bankId) {
@@ -541,15 +547,15 @@ AccountNumberCheck::Result method_56(const int *account, int *weight) {
 	return AccountNumberCheck::OK;
     return AccountNumberCheck::ERROR;
 }
-// Modified Method 57, valid from December, 4th 2006
+// Method 57 was last modified for due date 2013-09-09
 AccountNumberCheck::Result method_57(const int *account, int *weight) {
     int firstTwo = atoi(array2Number(account).substr(0, 2).c_str());
     int firstSix = atoi(array2Number(account).substr(0, 6).c_str());
     if(firstTwo == 0)	return AccountNumberCheck::ERROR;
     if(	( firstTwo >= 64 && firstTwo <= 66 ) ||
-	( firstTwo >= 75 && firstTwo <= 82 ) ||
+	( firstTwo >= 73 && firstTwo <= 82 ) ||
 	firstTwo == 51 || firstTwo == 55 || firstTwo == 61 ||
-	firstTwo == 70 || firstTwo == 73 || firstTwo == 88 ||
+	firstTwo == 70 || firstTwo == 88 ||
 	firstTwo == 94 || firstTwo == 95 ) {			// Variante 1
 	if ((777777 == firstSix) || (888888 == firstSix))	// Exception for variant 1
 	  return AccountNumberCheck::OK;
@@ -563,7 +569,7 @@ AccountNumberCheck::Result method_57(const int *account, int *weight) {
 	( firstTwo >= 83 && firstTwo <= 87 ) ||
 	( firstTwo >= 96 && firstTwo <= 98 ) ||
 	firstTwo == 62 || firstTwo == 63 || firstTwo == 71 ||
-	firstTwo == 72 || firstTwo == 74 || firstTwo == 89 ||
+	firstTwo == 72 || firstTwo == 89 ||
 	firstTwo == 90 || firstTwo == 92 || firstTwo == 93 ) {	// Variante 2
 	number2Array("1201212121", weight);
 	return algo01(10, weight, true, 3, account);
@@ -892,19 +898,27 @@ AccountNumberCheck::Result method_83(const int *account, int *weight) {
     number2Array("0087654320", weight);
     return algo01(11, weight, false, 10, account);
 }
+
+// method 84 was extended for due-date 2013-06-03
 AccountNumberCheck::Result method_84(const int *account, int *weight) {
     // exception "Ausnahme f. Sachkonten"
     if (9 == account[2])
 	return method_51_exception(account,weight);
 
-    // var 1
+    // Methode A
     number2Array("0000654320", weight);
     if (AccountNumberCheck::OK == algo01(11, weight, false, 10, account))
 	return AccountNumberCheck::OK;
 
-    // var2
-    return algo01(7, weight, false, 10, account);
+    // Methode B
+    if (AccountNumberCheck::OK == algo01(7, weight, false, 10, account))
+	return AccountNumberCheck::OK;
+
+    // Methode C
+    number2Array("0000212120", weight);
+    return algo01(10, weight, false, 10, account);
 }
+
 AccountNumberCheck::Result method_85(const int *account, int *weight) {
     // exception: (method "02" using modified weight)
     if (9 == account[2] && 9 == account[3]) {
@@ -1062,13 +1076,15 @@ AccountNumberCheck::Result method_94(const int *account, int *weight) {
     number2Array("1212121210", weight);
     return algo01(10, weight, true, 10, account);
 }
+// method 95 was changed for due-date 09.09.2013
 AccountNumberCheck::Result method_95(const int *account, int *weight) {
     // some numbers do not get checked
     std::string accNumber = array2Number(account);
     if (("0000000001" <= accNumber && accNumber <= "0001999999") ||
 	("0009000000" <= accNumber && accNumber <= "0025999999") ||
 	("0396000000" <= accNumber && accNumber <= "0499999999") ||
-	("0700000000" <= accNumber && accNumber <= "0799999999"))
+	("0700000000" <= accNumber && accNumber <= "0799999999") ||
+	("0910000000" <= accNumber && accNumber <= "0989999999"))
 	return AccountNumberCheck::OK;
 
     number2Array("4327654320", weight);
@@ -1436,7 +1452,7 @@ AccountNumberCheck::Result method_C5(const int *account, int *weight) {
     }
     return AccountNumberCheck::ERROR;
 }
-// method C6 was last changed for due-date June, 6 2011
+// method C6 was last changed for due-date March, 4 2013
 // checked with Bundesbank-Testnumbers
 AccountNumberCheck::Result method_C6(const int *account, int *weight) {
     number2Array("0121212120", weight);
@@ -1448,9 +1464,11 @@ AccountNumberCheck::Result method_C6(const int *account, int *weight) {
 	case 1:	mod_factor=33;	break;	// prefix="4451981"
 	case 2:	mod_factor=36;	break;	// prefix="4451992"
 	case 3:	mod_factor=38;	break;	// prefix="4451993"
+	case 4:	mod_factor=45;	break;	// prefix="4344992"
 	case 5:	mod_factor=41;	break;	// prefix="4344990"
 	case 6:	mod_factor=43;	break;	// prefix="4344991"
 	case 7:	mod_factor=31;	break;	// prefix="5499570"
+	case 8:	mod_factor=40;	break;	// prefix="4451994"
 	case 9:	mod_factor=40;	break;	// prefix="5499579"
 	default:
 	  return AccountNumberCheck::ERROR;
@@ -1495,9 +1513,9 @@ AccountNumberCheck::Result method_D0(const int *account, int *weight) {
 	return AccountNumberCheck::OK;				// variant 2, "method 9" again :-))
 }
 // method D1 was modified with due date starting from 7. June 2010
-// method D1 was last modified for due date 5. September 2011
+// method D1 was last modified for due date 2013-03-04
 AccountNumberCheck::Result method_D1(const int *account, int *weight) {
-    if (account[0] == 7 || account[0] == 8)
+    if (account[0] == 8)
 	return AccountNumberCheck::ERROR;
     // note: this method is quite similar to method_C6
     number2Array("2121212120", weight);
